@@ -1,8 +1,5 @@
 package Graphics::Potrace;
-{
-  $Graphics::Potrace::VERSION = '0.74';
-}
-
+$Graphics::Potrace::VERSION = '0.75';
 # ABSTRACT: bindings to the potrace library
 
 use strict;
@@ -21,9 +18,7 @@ use Exporter qw( import );
 }
 
 use XSLoader;
-our $VERSION;
-$VERSION ||= '0.1.0';
-XSLoader::load('Graphics::Potrace', $VERSION);
+XSLoader::load('Graphics::Potrace', $Graphics::Potrace::VERSION || '0.1');
 
 sub raster {
    return $_[0]    # return if already a raster... it might happen :)
@@ -80,7 +75,7 @@ Graphics::Potrace - bindings to the potrace library
 
 =head1 VERSION
 
-version 0.74
+version 0.75
 
 =head1 SYNOPSIS
 
@@ -101,7 +96,9 @@ version 0.74
    $vector->export(Svg => file => 'example.svg');
    $vector->export(Svg => file => \my $svg_dump);
    $vector->export(Svg => fh   => \*STDOUT);
-   my $eps = $vector->render('Eps');
+
+   # There is a simpler way to get a dump in a scalar
+   my $eps_dump = $vector->render('Eps');
 
    # All in one facility
    use Graphics::Potrace qw< trace >;
@@ -274,7 +271,7 @@ Flavio Poletti <polettix@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2013 by Flavio Poletti polettix@cpan.org.
+Copyright (C) 2011-2015 by Flavio Poletti polettix@cpan.org.
 
 This module is free software.  You can redistribute it and/or
 modify it under the terms of the Artistic License 2.0.
